@@ -92,8 +92,9 @@ class Vault:
         data = self.service.list(filter_expr)
         if len(data) > 0:
             sysout("%YELLOW%{} {}%NC%".format(
-                "\n=== Listing all vault entries",
-                f"matching \'{filter_expr}\' ===\n" if filter_expr else "===\n"))
+                "\n=== Listing all ({}) vault entries",
+                f"matching \'{filter_expr}\' ===\n" if filter_expr else "===\n",
+                len(data)))
             for entry in data:
                 sysout(entry.to_string())
         else:
